shill: Hook up Create/Pop/PushProfile to dbus

Have the manager profile methods written so far link up
with the RPC Manager Adaptor code.

BUG=chromium-os:24326
TEST=Unit tests for regression.  Also used flimflam's Python
create-profile/push-profile as well as logging out/in on a
shill instance running with --use-flimflam-profiles

Change-Id: I69f3a94e6cb3acda5ae37ec005b2345566e5e700
Reviewed-on: https://gerrit.chromium.org/gerrit/13070
Commit-Ready: Paul Stewart <pstew@chromium.org>
Reviewed-by: Paul Stewart <pstew@chromium.org>
Tested-by: Paul Stewart <pstew@chromium.org>
diff --git a/manager.h b/manager.h
index 9a56c64..63da1bc 100644
--- a/manager.h
+++ b/manager.h
@@ -79,10 +79,12 @@
   // Set up the profile list starting with a default profile along with
   // an (optional) list of startup profiles.
   void InitializeProfiles();
-  // Create a profile.  This does not affect the profile stack.
-  void CreateProfile(const std::string &name, Error *error);
+  // Create a profile.  This does not affect the profile stack.  Returns
+  // the RPC path of the created profile in |path|.
+  void CreateProfile(const std::string &name, std::string *path, Error *error);
   // Pushes existing profile with name |name| onto stack of managed profiles.
-  void PushProfile(const std::string &name, Error *error);
+  // Returns the RPC path of the pushed profile in |path|.
+  void PushProfile(const std::string &name, std::string *path, Error *error);
   // Pops profile named |name| off the top of the stack of managed profiles.
   void PopProfile(const std::string &name, Error *error);
   // Remove the active profile.